==> docs_sdk_archive_luna-sdk_droid_complete_rel_v.4.9.0.zip: docs_sdk_archive_luna-sdk_droid_complete_rel_v.4.9.0/doc/fsdk/html/hierarchy.js <==
var hierarchy =
[
    [ "fsdk::BaseDetection< Type >", "structfsdk_1_1_base_detection.html", null ],
    [ "fsdk::BaseDetection< ElementType >", "structfsdk_1_1_base_detection.html", null ],
    [ "fsdk::BaseRect< Type >", "structfsdk_1_1_base_rect.html", null ],
    [ "fsdk::BaseRect< ElementType >", "structfsdk_1_1_base_rect.html", null ],
    [ "fsdk::BaseRect< int >", "structfsdk_1_1_base_rect.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data", "unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html", null ],
    [ "fsdk::ISettingsProvider::Desc", "structfsdk_1_1_i_settings_provider_1_1_desc.html", null ],
    [ "fsdk::ISettingsProvider::Entry", "structfsdk_1_1_i_settings_provider_1_1_entry.html", null ],
    [ "fsdk::ErrorTraits< E >", "structfsdk_1_1_error_traits.html", null ],
    [ "fsdk::ErrorTraits< FSDKError >", "structfsdk_1_1_error_traits_3_01_f_s_d_k_error_01_4.html", null ],
    [ "fsdk::ErrorTraits< FutureError >", "structfsdk_1_1_error_traits_3_01_future_error_01_4.html", null ],
    [ "fsdk::ErrorTraits< IDescriptorBatch::Error >", "structfsdk_1_1_error_traits_3_01_i_descriptor_batch_1_1_error_01_4.html", null ],
    [ "fsdk::ErrorTraits< Image::Error >", "structfsdk_1_1_error_traits_3_01_image_1_1_error_01_4.html", null ],
    [ "fsdk::ErrorTraits< ISerializableObject::Error >", "structfsdk_1_1_error_traits_3_01_i_serializable_object_1_1_error_01_4.html", null ],
    [ "fsdk::ErrorTraits< ISettingsProvider::Error >", "structfsdk_1_1_error_traits_3_01_i_settings_provider_1_1_error_01_4.html", null ],
    [ "fsdk::ErrorTraits< MultiError< E0, E1 > >", "structfsdk_1_1_error_traits_3_01_multi_error_3_01_e0_00_01_e1_01_4_01_4.html", null ],
    [ "fsdk::ErrorTraits< PromiseError >", "structfsdk_1_1_error_traits_3_01_promise_error_01_4.html", null ],
    [ "fsdk::IBestShotQualityEstimator::EstimationResult", "structfsdk_1_1_i_best_shot_quality_estimator_1_1_estimation_result.html", null ],
    [ "fsdk::EyesEstimation::EyeAttributes", "structfsdk_1_1_eyes_estimation_1_1_eye_attributes.html", null ],
    [ "fsdk::EyeCropper", "structfsdk_1_1_eye_cropper.html", null ],
    [ "fsdk::EyesEstimation", "structfsdk_1_1_eyes_estimation.html", null ],
    [ "fsdk::EyeCropper::EyesRects", "structfsdk_1_1_eye_cropper_1_1_eyes_rects.html", null ],
    [ "fsdk::Face", "structfsdk_1_1_face.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Float1", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float1.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Float2", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float2.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Float3", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float3.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Float4", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float4.html", null ],
    [ "fsdk::Format", "structfsdk_1_1_format.html", null ],
    [ "fsdk::HeadPoseEstimation", "structfsdk_1_1_head_pose_estimation.html", null ],
    [ "fsdk::Human", "structfsdk_1_1_human.html", null ],
    [ "fsdk::HumanLandmark", "structfsdk_1_1_human_landmark.html", null ],
    [ "fsdk::HumanLandmarks< numOfLandmarks >", "structfsdk_1_1_human_landmarks.html", null ],
    [ "fsdk::IArchive", "structfsdk_1_1_i_archive.html", null ],
    [ "fsdk::IDetectionComparer", "classfsdk_1_1_i_detection_comparer.html", [
      [ "fsdk::FunctionDetectionComparer", "classfsdk_1_1_function_detection_comparer.html", null ]
    ] ],
    [ "fsdk::Image", "structfsdk_1_1_image.html", null ],
    [ "fsdk::In_place_t", "structfsdk_1_1_in__place__t.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Int1", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int1.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Int2", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int2.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Int3", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int3.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Int4", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int4.html", null ],
    [ "fsdk::IProgressTracker", "structfsdk_1_1_i_progress_tracker.html", null ],
    [ "fsdk::IRefCounted", "structfsdk_1_1_i_ref_counted.html", [
      [ "fsdk::IAGSEstimator", "structfsdk_1_1_i_a_g_s_estimator.html", null ],
      [ "fsdk::IAsyncContext", "structfsdk_1_1_i_async_context.html", null ],
      [ "fsdk::IBestShotQualityEstimator", "structfsdk_1_1_i_best_shot_quality_estimator.html", null ],
      [ "fsdk::IDescriptorExtractor", "structfsdk_1_1_i_descriptor_extractor.html", null ],
      [ "fsdk::IDescriptorMatcher", "structfsdk_1_1_i_descriptor_matcher.html", null ],
      [ "fsdk::IDetector", "structfsdk_1_1_i_detector.html", null ],
      [ "fsdk::IEyeEstimator", "structfsdk_1_1_i_eye_estimator.html", null ],
      [ "fsdk::IFaceEngineMobile", "structfsdk_1_1_i_face_engine_mobile.html", null ],
      [ "fsdk::IHeadPoseEstimator", "structfsdk_1_1_i_head_pose_estimator.html", null ],
      [ "fsdk::IHumanDetector", "structfsdk_1_1_i_human_detector.html", null ],
      [ "fsdk::IHumanWarper", "structfsdk_1_1_i_human_warper.html", null ],
      [ "fsdk::IIndex", "structfsdk_1_1_i_index.html", [
        [ "fsdk::IDenseIndex", "structfsdk_1_1_i_dense_index.html", null ],
        [ "fsdk::IDynamicIndex", "structfsdk_1_1_i_dynamic_index.html", null ]
      ] ],
      [ "fsdk::IIndexBuilder", "structfsdk_1_1_i_index_builder.html", null ],
      [ "fsdk::ILicense", "structfsdk_1_1_i_license.html", null ],
      [ "fsdk::IResultBatch< T >", "structfsdk_1_1_i_result_batch.html", null ],
      [ "fsdk::ISerializableObject", "structfsdk_1_1_i_serializable_object.html", [
        [ "fsdk::IDataStorageObject", "structfsdk_1_1_i_data_storage_object.html", [
          [ "fsdk::IDescriptor", "structfsdk_1_1_i_descriptor.html", null ],
          [ "fsdk::IDescriptorBatch", "structfsdk_1_1_i_descriptor_batch.html", null ]
        ] ]
      ] ],
      [ "fsdk::ISettingsProvider", "structfsdk_1_1_i_settings_provider.html", null ],
      [ "fsdk::IWarper", "structfsdk_1_1_i_warper.html", null ]
    ] ],
    [ "fsdk::IStaticDescriptorStorage", "structfsdk_1_1_i_static_descriptor_storage.html", [
      [ "fsdk::IDenseIndex", "structfsdk_1_1_i_dense_index.html", null ],
      [ "fsdk::IDynamicDescriptorStorage", "structfsdk_1_1_i_dynamic_descriptor_storage.html", [
        [ "fsdk::IDynamicIndex", "structfsdk_1_1_i_dynamic_index.html", null ],
        [ "fsdk::IIndexBuilder", "structfsdk_1_1_i_index_builder.html", null ]
      ] ]
    ] ],
    [ "fsdk::ISettingsProvider::Key", "structfsdk_1_1_i_settings_provider_1_1_key.html", null ],
    [ "fsdk::Landmarks< numOfLandmarks >", "structfsdk_1_1_landmarks.html", null ],
    [ "fsdk::Landmarks5Indexes", "structfsdk_1_1_landmarks5_indexes.html", null ],
    [ "fsdk::Landmarks< eyelidLandmarksCount >", "structfsdk_1_1_landmarks.html", null ],
    [ "fsdk::Landmarks< irisLandmarksCount >", "structfsdk_1_1_landmarks.html", null ],
    [ "fsdk::MatchingResult", "structfsdk_1_1_matching_result.html", [
      [ "fsdk::SearchResult", "structfsdk_1_1_search_result.html", null ]
    ] ],
    [ "fsdk::MultiError< E0, E1 >", "structfsdk_1_1_multi_error.html", null ],
    [ "fsdk::Noncopyable", "classfsdk_1_1_noncopyable.html", [
      [ "fsdk::Future< T >", "classfsdk_1_1_future.html", null ],
      [ "fsdk::Promise< T >", "classfsdk_1_1_promise.html", null ]
    ] ],
    [ "fsdk::Optional< BaseType >", "classfsdk_1_1_optional.html", null ],
    [ "fsdk::Optional< float >", "classfsdk_1_1_optional.html", null ],
    [ "fsdk::Optional< fsdk::HeadPoseEstimation >", "classfsdk_1_1_optional.html", null ],
    [ "fsdk::Optional< fsdk::HumanLandmarks >", "classfsdk_1_1_optional.html", null ],
    [ "fsdk::Optional< fsdk::Landmarks >", "classfsdk_1_1_optional.html", null ],
    [ "fsdk::Optional< fsdk::OrientationType >", "classfsdk_1_1_optional.html", null ],
    [ "fsdk::RefBase< T >", "structfsdk_1_1_ref_base.html", [
      [ "fsdk::Ref< T >", "structfsdk_1_1_ref.html", null ]
    ] ],
    [ "fsdk::Result< E >", "structfsdk_1_1_result.html", null ],
    [ "fsdk::Result< FSDKError >", "structfsdk_1_1_result.html", null ],
    [ "fsdk::Result< R >", "structfsdk_1_1_result.html", [
      [ "fsdk::ResultValue< R, V, Enable >", "structfsdk_1_1_result_value.html", null ],
      [ "fsdk::ResultValue< R, V, typename std::enable_if< std::is_copy_constructible< V >::value >::type >", "structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy2f668dc7084c0a905cc04d7f40fbec0b.html", null ],
      [ "fsdk::ResultValue< R, V, typename std::enable_if< std::is_copy_constructible< V >::value==false >::type >", "structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy9c4ba859f69d23768930bdaf370a25f8.html", null ]
    ] ],
    [ "fsdk::Sizer", "structfsdk_1_1_sizer.html", null ],
    [ "fsdk::Span< T >", "classfsdk_1_1_span.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::String", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_string.html", null ],
    [ "fsdk::SubImage", "structfsdk_1_1_sub_image.html", null ],
    [ "fsdk::Transformation", "structfsdk_1_1_transformation.html", null ],
    [ "fsdk::ISettingsProvider::Value", "structfsdk_1_1_i_settings_provider_1_1_value.html", null ],
    [ "fsdk::Vector2< T >", "structfsdk_1_1_vector2.html", null ],
    [ "fsdk::Vector2< float >", "structfsdk_1_1_vector2.html", null ],
    [ "fsdk::Vector2< int >", "structfsdk_1_1_vector2.html", null ],
    [ "fsdk::Version", "structfsdk_1_1_version.html", null ]
];

==> docs_sdk_archive_luna-sdk_droid_complete_rel_v.5.2.0.zip: docs_sdk_archive_luna-sdk_droid_complete_rel_v.5.2.0/doc/fsdk/html/hierarchy.js <==
var hierarchy =
[
    [ "fsdk::BaseRect< Type >", "structfsdk_1_1_base_rect.html", null ],
    [ "fsdk::BaseRect< float >", "structfsdk_1_1_base_rect.html", null ],
    [ "fsdk::BaseRect< int >", "structfsdk_1_1_base_rect.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data", "unionfsdk_1_1_i_settings_provider_1_1_value_1_1_data.html", null ],
    [ "fsdk::ISettingsProvider::Desc", "structfsdk_1_1_i_settings_provider_1_1_desc.html", null ],
    [ "fsdk::Detection", "structfsdk_1_1_detection.html", null ],
    [ "fsdk::ISettingsProvider::Entry", "structfsdk_1_1_i_settings_provider_1_1_entry.html", null ],
    [ "fsdk::ErrorTraits< E >", "structfsdk_1_1_error_traits.html", null ],
    [ "fsdk::ErrorTraits< FSDKError >", "structfsdk_1_1_error_traits_3_01_f_s_d_k_error_01_4.html", null ],
    [ "fsdk::ErrorTraits< FutureError >", "structfsdk_1_1_error_traits_3_01_future_error_01_4.html", null ],
    [ "fsdk::ErrorTraits< IDescriptorBatch::Error >", "structfsdk_1_1_error_traits_3_01_i_descriptor_batch_1_1_error_01_4.html", null ],
    [ "fsdk::ErrorTraits< Image::Error >", "structfsdk_1_1_error_traits_3_01_image_1_1_error_01_4.html", null ],
    [ "fsdk::ErrorTraits< ISerializableObject::Error >", "structfsdk_1_1_error_traits_3_01_i_serializable_object_1_1_error_01_4.html", null ],
    [ "fsdk::ErrorTraits< ISettingsProvider::Error >", "structfsdk_1_1_error_traits_3_01_i_settings_provider_1_1_error_01_4.html", null ],
    [ "fsdk::ErrorTraits< MultiError< E0, E1 > >", "structfsdk_1_1_error_traits_3_01_multi_error_3_01_e0_00_01_e1_01_4_01_4.html", null ],
    [ "fsdk::ErrorTraits< PromiseError >", "structfsdk_1_1_error_traits_3_01_promise_error_01_4.html", null ],
    [ "fsdk::IBestShotQualityEstimator::EstimationResult", "structfsdk_1_1_i_best_shot_quality_estimator_1_1_estimation_result.html", null ],
    [ "fsdk::EyesEstimation::EyeAttributes", "structfsdk_1_1_eyes_estimation_1_1_eye_attributes.html", null ],
    [ "fsdk::EyeCropper", "structfsdk_1_1_eye_cropper.html", null ],
    [ "fsdk::EyesEstimation", "structfsdk_1_1_eyes_estimation.html", null ],
    [ "fsdk::EyeCropper::EyesRects", "structfsdk_1_1_eye_cropper_1_1_eyes_rects.html", null ],
    [ "fsdk::Face", "structfsdk_1_1_face.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Float1", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float1.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Float2", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float2.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Float3", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float3.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Float4", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_float4.html", null ],
    [ "fsdk::Format", "structfsdk_1_1_format.html", null ],
    [ "fsdk::HeadPoseEstimation", "structfsdk_1_1_head_pose_estimation.html", null ],
    [ "fsdk::Human", "structfsdk_1_1_human.html", null ],
    [ "fsdk::HumanLandmark", "structfsdk_1_1_human_landmark.html", null ],
    [ "fsdk::HumanLandmarks< numOfLandmarks >", "structfsdk_1_1_human_landmarks.html", null ],
    [ "fsdk::IArchive", "structfsdk_1_1_i_archive.html", null ],
    [ "fsdk::IDetectionComparer", "classfsdk_1_1_i_detection_comparer.html", [
      [ "fsdk::FunctionDetectionComparer", "classfsdk_1_1_function_detection_comparer.html", null ]
    ] ],
    [ "fsdk::Image", "structfsdk_1_1_image.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Int1", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int1.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Int2", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int2.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Int3", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int3.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::Int4", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_int4.html", null ],
    [ "fsdk::IProgressTracker", "structfsdk_1_1_i_progress_tracker.html", null ],
    [ "fsdk::IRefCounted", "structfsdk_1_1_i_ref_counted.html", [
      [ "fsdk::IAGSEstimator", "structfsdk_1_1_i_a_g_s_estimator.html", null ],
      [ "fsdk::IAsyncContext", "structfsdk_1_1_i_async_context.html", null ],
      [ "fsdk::IBestShotQualityEstimator", "structfsdk_1_1_i_best_shot_quality_estimator.html", null ],
      [ "fsdk::IDescriptorExtractor", "structfsdk_1_1_i_descriptor_extractor.html", null ],
      [ "fsdk::IDescriptorMatcher", "structfsdk_1_1_i_descriptor_matcher.html", null ],
      [ "fsdk::IDetector", "structfsdk_1_1_i_detector.html", null ],
      [ "fsdk::IEyeEstimator", "structfsdk_1_1_i_eye_estimator.html", null ],
      [ "fsdk::IFaceDetectionBatch", "structfsdk_1_1_i_face_detection_batch.html", null ],
      [ "fsdk::IFaceEngineMobile", "structfsdk_1_1_i_face_engine_mobile.html", null ],
      [ "fsdk::IHeadPoseEstimator", "structfsdk_1_1_i_head_pose_estimator.html", null ],
      [ "fsdk::IHumanDetectionBatch", "structfsdk_1_1_i_human_detection_batch.html", null ],
      [ "fsdk::IHumanDetector", "structfsdk_1_1_i_human_detector.html", null ],
      [ "fsdk::IHumanWarper", "structfsdk_1_1_i_human_warper.html", null ],
      [ "fsdk::IIndex", "structfsdk_1_1_i_index.html", [
        [ "fsdk::IDenseIndex", "structfsdk_1_1_i_dense_index.html", null ],
        [ "fsdk::IDynamicIndex", "structfsdk_1_1_i_dynamic_index.html", null ]
      ] ],
      [ "fsdk::IIndexBuilder", "structfsdk_1_1_i_index_builder.html", null ],
      [ "fsdk::ILicense", "structfsdk_1_1_i_license.html", null ],
      [ "fsdk::IResultBatch< T >", "structfsdk_1_1_i_result_batch.html", null ],
      [ "fsdk::ISerializableObject", "structfsdk_1_1_i_serializable_object.html", [
        [ "fsdk::IDataStorageObject", "structfsdk_1_1_i_data_storage_object.html", [
          [ "fsdk::IDescriptor", "structfsdk_1_1_i_descriptor.html", null ],
          [ "fsdk::IDescriptorBatch", "structfsdk_1_1_i_descriptor_batch.html", null ]
        ] ]
      ] ],
      [ "fsdk::ISettingsProvider", "structfsdk_1_1_i_settings_provider.html", null ],
      [ "fsdk::IWarper", "structfsdk_1_1_i_warper.html", null ]
    ] ],
    [ "fsdk::IStaticDescriptorStorage", "structfsdk_1_1_i_static_descriptor_storage.html", [
      [ "fsdk::IDenseIndex", "structfsdk_1_1_i_dense_index.html", null ],
      [ "fsdk::IDynamicDescriptorStorage", "structfsdk_1_1_i_dynamic_descriptor_storage.html", [
        [ "fsdk::IDynamicIndex", "structfsdk_1_1_i_dynamic_index.html", null ],
        [ "fsdk::IIndexBuilder", "structfsdk_1_1_i_index_builder.html", null ]
      ] ]
    ] ],
    [ "fsdk::ISettingsProvider::Key", "structfsdk_1_1_i_settings_provider_1_1_key.html", null ],
    [ "fsdk::Landmarks< numOfLandmarks >", "structfsdk_1_1_landmarks.html", null ],
    [ "fsdk::Landmarks5Indexes", "structfsdk_1_1_landmarks5_indexes.html", null ],
    [ "fsdk::Landmarks< eyelidLandmarksCount >", "structfsdk_1_1_landmarks.html", null ],
    [ "fsdk::Landmarks< irisLandmarksCount >", "structfsdk_1_1_landmarks.html", null ],
    [ "fsdk::LaunchOptions", "structfsdk_1_1_launch_options.html", null ],
    [ "fsdk::MatchingResult", "structfsdk_1_1_matching_result.html", [
      [ "fsdk::SearchResult", "structfsdk_1_1_search_result.html", null ]
    ] ],
    [ "fsdk::MultiError< E0, E1 >", "structfsdk_1_1_multi_error.html", null ],
    [ "fsdk::Noncopyable", "classfsdk_1_1_noncopyable.html", [
      [ "fsdk::Future< T >", "classfsdk_1_1_future.html", null ],
      [ "fsdk::Promise< T >", "classfsdk_1_1_promise.html", null ]
    ] ],
    [ "fsdk::RefBase< T >", "structfsdk_1_1_ref_base.html", [
      [ "fsdk::Ref< T >", "structfsdk_1_1_ref.html", null ]
    ] ],
    [ "fsdk::Result< E >", "structfsdk_1_1_result.html", null ],
    [ "fsdk::Result< R >", "structfsdk_1_1_result.html", [
      [ "fsdk::ResultValue< R, V, Enable >", "structfsdk_1_1_result_value.html", null ],
      [ "fsdk::ResultValue< R, V, typename std::enable_if< std::is_copy_constructible< V >::value >::type >", "structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy2f668dc7084c0a905cc04d7f40fbec0b.html", null ],
      [ "fsdk::ResultValue< R, V, typename std::enable_if< std::is_copy_constructible< V >::value==false >::type >", "structfsdk_1_1_result_value_3_01_r_00_01_v_00_01typename_01std_1_1enable__if_3_01std_1_1is__copy9c4ba859f69d23768930bdaf370a25f8.html", null ]
    ] ],
    [ "fsdk::Sizer", "structfsdk_1_1_sizer.html", null ],
    [ "fsdk::Span< T >", "classfsdk_1_1_span.html", null ],
    [ "fsdk::ISettingsProvider::Value::Data::String", "structfsdk_1_1_i_settings_provider_1_1_value_1_1_data_1_1_string.html", null ],
    [ "fsdk::SubImage", "structfsdk_1_1_sub_image.html", null ],
    [ "fsdk::Transformation", "structfsdk_1_1_transformation.html", null ],
    [ "fsdk::ISettingsProvider::Value", "structfsdk_1_1_i_settings_provider_1_1_value.html", null ],
    [ "fsdk::Vector2< T >", "structfsdk_1_1_vector2.html", null ],
    [ "fsdk::Vector2< float >", "structfsdk_1_1_vector2.html", null ],
    [ "fsdk::Vector2< int >", "structfsdk_1_1_vector2.html", null ],
    [ "fsdk::Version", "structfsdk_1_1_version.html", null ]
];
